@@ -41,11 +41,16 @@
 extern "C" {
 #endif
 
+/* allow version to be specified via compile line define */
+#ifndef XMLRPC_LIB_VERSION
+ #define XMLRPC_LIB_VERSION "0.54"
+#endif
+
 /* this number, representing the date, must be increased each time the API changes */
 #define XMLRPC_API_NO 20020623
 
 /* this string should be changed with each packaged release */
-#define XMLRPC_VERSION_STR "xmlrpc-epi v. " VERSION
+#define XMLRPC_VERSION_STR "xmlrpc-epi v. " XMLRPC_LIB_VERSION
 
 /* where to find more info. shouldn't need to change much */
 #define XMLRPC_HOME_PAGE_STR "http://xmlprc-epi.sourceforge.net/"
@@ -114,9 +119,9 @@ typedef enum _XMLRPC_VALUE_TYPE_EASY {
    xmlrpc_type_int,                /* integer                        */
    xmlrpc_type_string,             /* string                         */
 /* -- IMPORTANT: identical to XMLRPC_VALUE_TYPE to this point. --   */
-	xmlrpc_type_array,              /* vector array                   */
-	xmlrpc_type_mixed,              /* vector mixed                   */
-	xmlrpc_type_struct              /* vector struct                  */
+    xmlrpc_type_array,              /* vector array                   */
+    xmlrpc_type_mixed,              /* vector mixed                   */
+    xmlrpc_type_struct              /* vector struct                  */
 } XMLRPC_VALUE_TYPE_EASY;
 /*******/
 
@@ -174,6 +179,20 @@ typedef enum _xmlrpc_error_code {
 #define xmlrpc_error_transport_str              "transport error."
 
 
+/****d* VALUE/XMLRPC_SERVER_VALIDATION
+ * NAME
+ *   XMLRPC_SERVER_VALIDATION
+ * NOTES
+ *   Defines if/how server validates incoming requests according to introspection data
+ * SOURCE
+ */
+typedef enum _xmlrpc_server_validation {
+   validation_none = 0,          /* no validation                                                */ 
+   validation_all = 1,           /* all methods must validate                                    */ 
+   validation_if_defined = 2    /* all methods with defined introspection params must validate  */ 
+} XMLRPC_SERVER_VALIDATION;
+/******/
+
 
 /****d* VALUE/XMLRPC_VERSION
  * NAME
@@ -190,7 +209,7 @@ typedef enum _xmlrpc_version {
    xmlrpc_version_1_0 = 1,       /* xmlrpc 1.0 standard vocab      */ 
    xmlrpc_version_simple = 2,    /* alt more readable vocab        */ 
    xmlrpc_version_danda = 2,     /* same as simple. legacy         */
-	xmlrpc_version_soap_1_1 = 3	/* SOAP. version 1.1              */
+    xmlrpc_version_soap_1_1 = 3    /* SOAP. version 1.1              */
 } XMLRPC_VERSION;
 /******/
 
@@ -299,9 +318,9 @@ typedef XMLRPC_VALUE (*XMLRPC_Callback)(XMLRPC_SERVER server, XMLRPC_REQUEST inp
 /******/
 
 /* ID Case Defaults */
-XMLRPC_CASE XMLRPC_GetDefaultIdCase();
+XMLRPC_CASE XMLRPC_GetDefaultIdCase(void);
 XMLRPC_CASE XMLRPC_SetDefaultIdCase(XMLRPC_CASE id_case);
-XMLRPC_CASE_COMPARISON XMLRPC_GetDefaultIdCaseComparison();
+XMLRPC_CASE_COMPARISON XMLRPC_GetDefaultIdCaseComparison(void);
 XMLRPC_CASE_COMPARISON XMLRPC_SetDefaultIdCaseComparison(XMLRPC_CASE_COMPARISON id_case);
 
 /* Vector manipulation */
@@ -323,7 +342,7 @@ XMLRPC_VALUE XMLRPC_CreateValueDateTime_ISO8601(const char* id, const char *s);
 XMLRPC_VALUE XMLRPC_CreateValueDouble(const char* id, double f);
 XMLRPC_VALUE XMLRPC_CreateValueInt(const char* id, int i);
 XMLRPC_VALUE XMLRPC_CreateValueString(const char* id, const char* s, int len);
-XMLRPC_VALUE XMLRPC_CreateValueEmpty();
+XMLRPC_VALUE XMLRPC_CreateValueEmpty(void);
 XMLRPC_VALUE XMLRPC_CreateVector(const char* id, XMLRPC_VECTOR_TYPE type);
 
 /* Cleanup values */
@@ -373,7 +392,7 @@ char* XMLRPC_VALUE_ToXML(XMLRPC_VALUE val, int* buf_len);
 /* Request manipulation funcs */
 const char* XMLRPC_RequestSetMethodName(XMLRPC_REQUEST request, const char* methodName);
 const char* XMLRPC_RequestGetMethodName(XMLRPC_REQUEST request);
-XMLRPC_REQUEST XMLRPC_RequestNew();
+XMLRPC_REQUEST XMLRPC_RequestNew(void);
 void XMLRPC_RequestFree(XMLRPC_REQUEST request, int bFreeIO);
 XMLRPC_REQUEST_OUTPUT_OPTIONS XMLRPC_RequestSetOutputOptions(XMLRPC_REQUEST request, XMLRPC_REQUEST_OUTPUT_OPTIONS output);
 XMLRPC_REQUEST_OUTPUT_OPTIONS XMLRPC_RequestGetOutputOptions(XMLRPC_REQUEST request);
@@ -383,8 +402,8 @@ XMLRPC_REQUEST_TYPE XMLRPC_RequestSetRequestType(XMLRPC_REQUEST request, XMLRPC_
 XMLRPC_REQUEST_TYPE XMLRPC_RequestGetRequestType(XMLRPC_REQUEST request);
 
 /* Server Creation/Destruction; Method Registration and Invocation */
-XMLRPC_SERVER XMLRPC_ServerCreate();
-XMLRPC_SERVER XMLRPC_GetGlobalServer();   /* better to use XMLRPC_ServerCreate if you can */
+XMLRPC_SERVER XMLRPC_ServerCreate(void);
+XMLRPC_SERVER XMLRPC_GetGlobalServer(void);   /* better to use XMLRPC_ServerCreate if you can */
 void XMLRPC_ServerDestroy(XMLRPC_SERVER server);
 int XMLRPC_ServerRegisterMethod(XMLRPC_SERVER server, const char *name, XMLRPC_Callback cb);
 XMLRPC_Callback XMLRPC_ServerFindMethod(XMLRPC_SERVER server, const char* callName);
@@ -404,7 +423,7 @@ const char* XMLRPC_GetResponseFaultString (XMLRPC_REQUEST response);
 /* Public Utility funcs */
 XMLRPC_VALUE XMLRPC_UtilityCreateFault(int fault_code, const char* fault_string);
 void XMLRPC_Free(void* mem);
-const char*  XMLRPC_GetVersionString();
+const char*  XMLRPC_GetVersionString(void);
 
 /****d* VALUE/XMLRPC_MACROS
  * NAME
